
.. include:: links.rst

Installation
============
Make sure all of *eddymotion*' `External Dependencies`_ are installed.

On a functional Python 3.7 (or above) environment with ``pip`` installed,
*eddymotion* can be installed using the habitual command ::

    $ python -m pip install eddymotion

Check your installation with the following command line ::

    $ python -c "from eddymotion import __version__; print(__version__)"


External Dependencies
---------------------
*eddymotion* requires DIPY_, and ANTs_.
